@@ -203,7 +203,8 @@ class HTTPClient:
                     kwargs['data'] = form_data
                 try:
                     async with self.__session.request(method, url, **kwargs) as response:
-                        _log.debug('%s %s 与 %s 已返回 %s', method, url, kwargs.get('data'), response.status)
+                        _log.debug('%s %s 与 %s 已返回 %s Trace ID: %s', method, url, kwargs.get('data'),
+                                   response.status, response.headers['X-Tps-trace-ID'])
 
                         # even errors have text involved in them so this is safe to call
                         data = await json_or_text(response)
